==> haskell-interpolate-0.2.0-64-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolate
version: 0.2.0
id: interpolate-0.2.0-1PtkDSVMmKVEbjr2zbJzpV
key: interpolate-0.2.0-1PtkDSVMmKVEbjr2zbJzpV
license: MIT
copyright: (c) 2013-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: https://github.com/sol/interpolate#readme
synopsis: String interpolation done right
description:
    String interpolation done right
category: Data, Text
abi: 60c60767f9a324b6e3b8adc5113d43ad
exposed: True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util
hidden-modules: Data.String.Interpolate.Compat
                Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
                Paths_interpolate
import-dirs: /usr/lib/ghc-8.6.3/site-local/interpolate-0.2.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/interpolate-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/interpolate-0.2.0
hs-libraries: HSinterpolate-0.2.0-1PtkDSVMmKVEbjr2zbJzpV
depends:
    base-4.12.0.0 haskell-src-meta-0.8.2-6J5qDWgo44KGIfgaWwSkVg
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html: /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolate-0.2.0-70-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolate
version: 0.2.0
id: interpolate-0.2.0-G1w9qDnHJqWFN19TBTK7ia
key: interpolate-0.2.0-G1w9qDnHJqWFN19TBTK7ia
license: MIT
copyright: (c) 2013-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: https://github.com/sol/interpolate#readme
synopsis: String interpolation done right
description:
    String interpolation done right
category: Data, Text
abi: cef5e52b3e6c6eb775d374a8bf7a0fcf
exposed: True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util
hidden-modules: Data.String.Interpolate.Compat
                Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
                Paths_interpolate
import-dirs: /usr/lib/ghc-8.6.4/site-local/interpolate-0.2.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/interpolate-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/interpolate-0.2.0
hs-libraries: HSinterpolate-0.2.0-G1w9qDnHJqWFN19TBTK7ia
depends:
    base-4.12.0.0 haskell-src-meta-0.8.2-8ADbVF5VqZcIuW9XL3cCSz
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html: /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
